# `sxs.load`

One of the main goals of the `sxs` package is to provide a simple and
consistent interface to the data provided by the SXS Collaboration.
The `sxs.load` function is the primary way to access the data,
ensuring that users do not need to understand the underlying data
formats, while also allowing the collaboration to change those formats
without affecting the user interface.


::: sxs.load
